==> msqrole-1.0.0.tar.gz: msqrole/src/Form/MasqueradeRoleSettings.php <==
<?php

namespace Drupal\msqrole\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\msqrole\RoleManagerInterface;

/**
 * Class MasqueradeRoleSettings
 *
 * @package Drupal\msqrole\Form
 */
class MasqueradeRoleSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'msqrole_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('msqrole.settings');

    // Tags
    $form['tags'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Extra tags to invalidate:'),
      '#default_value' => implode(PHP_EOL, unserialize($config->get('tags_to_invalidate'))),
      '#description' => $this->t('These tags will be invalidated when changing roles. Each tag gets a new line.'),
    ];

    $form['default_tags'] = [
      '#type' => 'inline_template',
      '#template' => '<strong>Default enabled tags:</strong><pre>{{ tags }}</pre>',
      '#context' => [
        'tags' => print_r(implode('<br />',
          array_merge(RoleManagerInterface::tagsToInvalidate, ['user:<i>{current_user.id}</i>'])), TRUE)
      ]
    ];


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('msqrole.settings');
    $tags = explode(PHP_EOL, $form_state->getValue('tags'));
    foreach ($tags as &$tag) {
      $tag = trim($tag);
    }
    $config->set('tags_to_invalidate', serialize($tags ?? []));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'msqrole.settings',
    ];
  }

}

==> msqrole-1.0.1.tar.gz: msqrole/src/Form/MasqueradeRoleSettings.php <==
<?php

namespace Drupal\msqrole\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\msqrole\RoleManagerInterface;

/**
 * Class MasqueradeRoleSettings
 *
 * @package Drupal\msqrole\Form
 */
class MasqueradeRoleSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'msqrole_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);
    $config = $this->config('msqrole.settings');

    // Tags
    $form['tags'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Extra tags to invalidate:'),
      '#default_value' => implode(PHP_EOL, unserialize($config->get('tags_to_invalidate'))),
      '#description' => $this->t('These tags will be invalidated when changing roles. Each tag gets a new line.'),
    ];

    $form['default_tags'] = [
      '#type' => 'inline_template',
      '#template' => '<strong>Default enabled tags:</strong><pre>{{ tags }}</pre>',
      '#context' => [
        'tags' => print_r(implode('<br />',
          array_merge(RoleManagerInterface::TAGSTOINVALIDATE, ['user:<i>{current_user.id}</i>'])), TRUE)
      ]
    ];


    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('msqrole.settings');
    $tags = explode(PHP_EOL, $form_state->getValue('tags'));
    foreach ($tags as &$tag) {
      $tag = trim($tag);
    }
    $config->set('tags_to_invalidate', serialize($tags ?? []));
    $config->save();
    return parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'msqrole.settings',
    ];
  }

}
